@@ -1,3 +1,25 @@
+/*************************************************************************
+ *                                                                       *
+ * Open Dynamics Engine, Copyright (C) 2001,2002 Russell L. Smith.       *
+ * All rights reserved.  Email: russ@q12.org   Web: www.q12.org          *
+ *                                                                       *
+ * This library is free software; you can redistribute it and/or         *
+ * modify it under the terms of EITHER:                                  *
+ *   (1) The GNU Lesser General Public License as published by the Free  *
+ *       Software Foundation; either version 2.1 of the License, or (at  *
+ *       your option) any later version. The text of the GNU Lesser      *
+ *       General Public License is included with this library in the     *
+ *       file LICENSE.TXT.                                               *
+ *   (2) The BSD-style license that is included with this library in     *
+ *       the file LICENSE-BSD.TXT.                                       *
+ *                                                                       *
+ * This library is distributed in the hope that it will be useful,       *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the files    *
+ * LICENSE.TXT and LICENSE-BSD.TXT for more details.                     *
+ *                                                                       *
+ *************************************************************************/
+
 // Test my Plane2D constraint.
 // Uses ode-0.35 collision API.
 
@@ -34,8 +56,6 @@ static dJointGroup
 static void     cb_start ()
 /*************************/
 {
-	dAllocateODEDataForThread(dAllocateMaskAll);
-
     static float    xyz[3] = { 0.5f*STAGE_SIZE, 0.5f*STAGE_SIZE, 0.65f*STAGE_SIZE};
     static float    hpr[3] = { 90.0f, -90.0f, 0 };
 
@@ -44,7 +64,7 @@ static void     cb_start ()
 
 
 
-static void     cb_near_collision (void *data, dGeomID o1, dGeomID o2)
+static void     cb_near_collision (void *, dGeomID o1, dGeomID o2)
 /********************************************************************/
 {
     dBodyID     b1 = dGeomGetBody (o1);
@@ -194,7 +214,7 @@ extern int      main
     dsFunctions drawstuff_functions;
 
 
-	 dInitODE2(0);
+    dInitODE();
 
     // dynamic world
 
